@@ -37,12 +37,14 @@ ResultFileName="$4"
 
 thread_num="$5"
 
+BASE_DIR="$6"
+
 # Parallelization Here
 begin=$(date +%s)
 # Creating .hits_sorted file name table
 find $FolderName/*.hits_sorted > CLUSTER_File_Name.txt
 
-find $FolderName/*.hits_sorted | parallel -j $thread_num "echo Processing {};python GetIcityForBLASTHits.py -f {} -o {.}.tsv -d $DBPath -c $ClustersFileName"
+find $FolderName/*.hits_sorted | parallel -j $thread_num "echo Processing {};python $BASE_DIR/GetIcityForBLASTHits.py -f {} -o {.}.tsv -d $DBPath -c $ClustersFileName"
 cat $FolderName/*.tsv > $ResultFileName
 end=$(date +%s)
 spend=$(expr $end - $begin)
